@@ -192,8 +192,6 @@ static void
 async_failed (AsyncData *async, GError *error)
 {
 	g_propagate_error (&async->loader->priv->error, error);
-	g_error_free (error);
-
 	remote_load_completed_or_failed (async->loader, async);
 }
 
@@ -203,9 +201,9 @@ async_read_cb (GInputStream *stream,
 	       AsyncData    *async)
 {
 	gedit_debug (DEBUG_LOADER);
-	GError *error = NULL;
 	GeditGioDocumentLoader *gvloader;
 	gssize bytes_read;
+	GError *error = NULL;
 	
 	/* manually check cancelled state */
 	if (g_cancellable_is_cancelled (async->cancellable))
@@ -311,47 +309,13 @@ finish_query_info (AsyncData *async)
 }
 
 static void
-remote_get_file_info_cb (GFile        *source,
-			 GAsyncResult *res,
-			 AsyncData    *async)
+query_info_cb (GFile        *source,
+	       GAsyncResult *res,
+	       AsyncData    *async)
 {
 	GeditGioDocumentLoader *gvloader;
 	GError *error = NULL;
-	
-	gedit_debug (DEBUG_LOADER);
-	
-	/* manually check the cancelled state */
-	if (g_cancellable_is_cancelled (async->cancellable))
-	{
-		async_data_free (async);
-		return;
-	}
 
-	gvloader = async->loader;
-	
-	/* finish the info query */
-	gvloader->priv->info = g_file_query_info_finish (gvloader->priv->gfile,
-	                                                 res, 
-	                                                 &error);
-
-	if (!gvloader->priv->info)
-	{
-		/* propagate the error and clean up */
-		async_failed (async, error);
-		return;
-	}
-
-	finish_query_info (async);
-}
-
-static void
-remote_get_info_cb (GFileInputStream *source,
-		    GAsyncResult     *res,
-		    AsyncData        *async)
-{
-	GeditGioDocumentLoader *gvloader;
-	GError *error = NULL;
-	
 	gedit_debug (DEBUG_LOADER);
 
 	/* manually check the cancelled state */
@@ -362,29 +326,14 @@ remote_get_info_cb (GFileInputStream *source,
 	}	
 
 	gvloader = async->loader;
-	
+
 	/* finish the info query */
-	gvloader->priv->info = g_file_input_stream_query_info_finish (gvloader->priv->stream,
-	                                                              res, 
-	                                                              &error);
+	gvloader->priv->info = g_file_query_info_finish (gvloader->priv->gfile,
+	                                                 res, 
+	                                                 &error);
 
 	if (gvloader->priv->info == NULL)
 	{
-		if (error->code == G_IO_ERROR_NOT_SUPPORTED)
-		{
-			gedit_debug_message (DEBUG_LOADER, "Query info not supported on stream, trying on file");
-
-			/* then try to query the info using g_file_query_info */
-			g_file_query_info_async (gvloader->priv->gfile,
-						 REMOTE_QUERY_ATTRIBUTES,
-						 G_FILE_QUERY_INFO_NONE,
-						 G_PRIORITY_HIGH,
-						 async->cancellable,
-						 (GAsyncReadyCallback)remote_get_file_info_cb,
-						 async);
-			return;
-		}
-		
 		/* propagate the error and clean up */
 		async_failed (async, error);
 		return;
@@ -424,15 +373,15 @@ mount_ready_callback (GFile        *file,
 static void
 recover_not_mounted (AsyncData *async)
 {
-	GeditDocumentLoader *loader;
+	GeditDocument *doc;
 	GMountOperation *mount_operation;
 
 	gedit_debug (DEBUG_LOADER);
 
+	doc = gedit_document_loader_get_document (GEDIT_DOCUMENT_LOADER (async->loader));
+	mount_operation = _gedit_document_create_mount_operation (doc);
+
 	async->tried_mount = TRUE;
-	loader = GEDIT_DOCUMENT_LOADER (async->loader);
-	mount_operation = _gedit_document_create_mount_operation (loader->document);
-	
 	g_file_mount_enclosing_volume (async->loader->priv->gfile,
 				       G_MOUNT_MOUNT_NONE,
 				       mount_operation,
@@ -478,19 +427,23 @@ async_read_ready_callback (GObject      *source,
 					       TRUE,
 					       gvloader->priv->error);
 
-		g_error_free (error);
 		async_data_free (async);
+		return;
 	}
-	else
-	{
-		/* get the file info from the input stream */
-		g_file_input_stream_query_info_async (gvloader->priv->stream,
-						      REMOTE_QUERY_ATTRIBUTES,
-						      G_PRIORITY_HIGH,
-						      gvloader->priv->cancellable,
-						      (GAsyncReadyCallback) remote_get_info_cb,
-						      async);
-	}
+
+	/* get the file info: note we cannot use 
+	 * g_file_input_stream_query_info_async since it is not able to get the
+	 * content type etc, beside it is not supported by gvfs.
+	 * Using the file instead of the stream is slightly racy, but for
+	 * loading this is not too bad...
+	 */
+	g_file_query_info_async (gvloader->priv->gfile,
+				 REMOTE_QUERY_ATTRIBUTES,
+                                 G_FILE_QUERY_INFO_NONE,
+				 G_PRIORITY_HIGH,
+				 async->cancellable,
+				 (GAsyncReadyCallback) query_info_cb,
+				 async);
 }
 
 static void
