@@ -27,26 +27,22 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-utils.h 6368 2008-08-09 13:37:59Z jessevdk $
+ * $Id$
  */
 
 #ifndef __GEDIT_UTILS_H__
 #define __GEDIT_UTILS_H__
 
 #include <glib.h>
-#include <gtk/gtkwidget.h>
-#include <gtk/gtkdialog.h>
-#include <gtk/gtkaboutdialog.h>
-#include <gtk/gtkmenu.h>
-#include <gtk/gtktextiter.h>
+#include <gtk/gtk.h>
 #include <atk/atk.h>
 #include <gedit/gedit-encodings.h>
 
 G_BEGIN_DECLS
 
 /* useful macro */
-#define GBOOLEAN_TO_POINTER(i) ((gpointer) ((i) ? 2 : 1))
-#define GPOINTER_TO_BOOLEAN(i) ((gboolean) ((((gint)(i)) == 2) ? TRUE : FALSE))
+#define GBOOLEAN_TO_POINTER(i) (GINT_TO_POINTER ((i) ? 2 : 1))
+#define GPOINTER_TO_BOOLEAN(i) ((gboolean) ((GPOINTER_TO_INT(i) == 2) ? TRUE : FALSE))
 
 #define IS_VALID_BOOLEAN(v) (((v == TRUE) || (v == FALSE)) ? TRUE : FALSE)
 
@@ -84,6 +80,9 @@ gchar		*gedit_utils_escape_underscores		(const gchar *text,
 gchar		*gedit_utils_str_middle_truncate	(const gchar *string, 
 							 guint        truncate_length);
 
+gchar		*gedit_utils_str_end_truncate		(const gchar *string,
+							 guint        truncate_length);
+
 gboolean	 g_utf8_caselessnmatch			(const char *s1,
 							 const char *s2,
 							 gssize n1,
@@ -103,20 +102,18 @@ gchar		*gedit_utils_escape_search_text		(const gchar *text);
 
 gchar		*gedit_utils_unescape_search_text	(const gchar *text);
 
-gchar		*gedit_utils_get_stdin			(void);
-
 void		 gedit_warning				(GtkWindow  *parent,
 							 const gchar *format,
 							 ...) G_GNUC_PRINTF(2, 3);
 
-gchar		*gedit_utils_str_middle_truncate	(const char *string,
-							 guint truncate_length);
-
 gchar		*gedit_utils_make_valid_utf8		(const char *name);
 
 /* Note that this function replace home dir with ~ */
 gchar		*gedit_utils_uri_get_dirname		(const char *uri);
 
+gchar		*gedit_utils_location_get_dirname_for_display
+							(GFile *location);
+
 gchar		*gedit_utils_replace_home_dir_with_tilde (const gchar *uri);
 
 guint		 gedit_utils_get_current_workspace	(GdkScreen *screen);
