@@ -47,10 +47,7 @@
 #include "gedit-prefs-manager-app.h"
 #include "gedit-marshal.h"
 #include "gedit-utils.h"
-/* FIXME: Remove this when using for more things gtk+ >= 2.15.0 */
-#if !GTK_CHECK_VERSION (2, 15, 0)
-#include "sexy-icon-entry.h"
-#endif
+
 
 #define GEDIT_VIEW_SCROLL_MARGIN 0.02
 #define GEDIT_VIEW_SEARCH_DIALOG_TIMEOUT (30*1000) /* 30 seconds */
@@ -114,19 +111,19 @@ static gboolean gedit_view_drag_motion		(GtkWidget        *widget,
 						 GdkDragContext   *context,
 						 gint              x,
 						 gint              y,
-						 guint             time);
+						 guint             timestamp);
 static void     gedit_view_drag_data_received   (GtkWidget        *widget,
 						 GdkDragContext   *context,
 						 gint              x,
 						 gint              y,
 						 GtkSelectionData *selection_data,
 						 guint             info,
-						 guint             time);
+						 guint             timestamp);
 static gboolean gedit_view_drag_drop		(GtkWidget        *widget,
 	      					 GdkDragContext   *context,
 	      					 gint              x,
 	      					 gint              y,
-	      					 guint             time);
+	      					 guint             timestamp);
 static gboolean	gedit_view_button_press_event	(GtkWidget        *widget,
 						 GdkEventButton   *event);
 
@@ -1325,6 +1322,7 @@ search_entry_insert_text (GtkEditable *editable,
 
 			if (!g_unichar_isdigit (c)) {
 				g_signal_stop_emission_by_name (editable, "insert_text");
+				gtk_widget_error_bell (view->priv->search_entry);
 				break;
 			}
 
@@ -1371,36 +1369,6 @@ search_entry_insert_text (GtkEditable *editable,
 static void
 customize_for_search_mode (GeditView *view)
 {
-/*
- * FIXME: Remove all this ifdef once we require gtk+ >= 2.15.0 for other things
- */
-#if !GTK_CHECK_VERSION (2, 15, 0)
-	GtkWidget *icon;
-	
-	if (view->priv->search_mode == SEARCH)
-	{
-		icon = gtk_image_new_from_stock (GTK_STOCK_FIND,
-						 GTK_ICON_SIZE_MENU);
-
-		gtk_widget_set_tooltip_text (view->priv->search_entry,
-					     _("String you want to search for"));
-	}
-	else
-	{
-		icon = gtk_image_new_from_stock (GTK_STOCK_JUMP_TO,
-						 GTK_ICON_SIZE_MENU);
-
-		gtk_widget_set_tooltip_text (view->priv->search_entry,
-					     _("Line you want to move the cursor to"));
-	}
-	
-	gtk_widget_show (icon);
-	sexy_icon_entry_set_icon (SEXY_ICON_ENTRY(view->priv->search_entry),
-				  SEXY_ICON_ENTRY_PRIMARY,
-				  GTK_IMAGE (icon));
-
-	g_object_unref (icon);
-#else
 	if (view->priv->search_mode == SEARCH)
 	{
 		gtk_entry_set_icon_from_stock (GTK_ENTRY (view->priv->search_entry),
@@ -1419,7 +1387,6 @@ customize_for_search_mode (GeditView *view)
 		gtk_widget_set_tooltip_text (view->priv->search_entry,
 					     _("Line you want to move the cursor to"));
 	}
-#endif
 }
 
 static gboolean
@@ -1537,11 +1504,7 @@ ensure_search_window (GeditView *view)
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 3);
 
 	/* add entry */
-#if GTK_CHECK_VERSION (2, 15, 0)
 	view->priv->search_entry = gtk_entry_new ();
-#else
-	view->priv->search_entry = sexy_icon_entry_new ();
-#endif
 	gtk_widget_show (view->priv->search_entry);
 	
 	g_signal_connect (view->priv->search_entry, "populate_popup",
@@ -1934,19 +1897,19 @@ gedit_view_drag_motion (GtkWidget      *widget,
 			GdkDragContext *context,
 			gint            x,
 			gint            y,
-			guint           time)
+			guint           timestamp)
 {
 	gboolean result;
 
 	/* Chain up to allow textview to scroll and position dnd mark, note 
 	 * that this needs to be checked if gtksourceview or gtktextview
 	 * changes drag_motion behaviour */
-	result = GTK_WIDGET_CLASS (gedit_view_parent_class)->drag_motion (widget, context, x, y, time);
+	result = GTK_WIDGET_CLASS (gedit_view_parent_class)->drag_motion (widget, context, x, y, timestamp);
 
 	/* If this is a URL, deal with it here */
 	if (drag_get_uri_target (widget, context) != GDK_NONE) 
 	{
-		gdk_drag_status (context, context->suggested_action, time);
+		gdk_drag_status (context, context->suggested_action, timestamp);
 		result = TRUE;
 	}
 
@@ -1960,7 +1923,7 @@ gedit_view_drag_data_received (GtkWidget        *widget,
 			       gint              y,
 			       GtkSelectionData *selection_data,
 			       guint             info,
-			       guint             time)
+			       guint             timestamp)
 {
 	gchar **uri_list;
 	
@@ -1974,12 +1937,12 @@ gedit_view_drag_data_received (GtkWidget        *widget,
 			g_signal_emit (widget, view_signals[DROP_URIS], 0, uri_list);
 			g_strfreev (uri_list);
 			
-			gtk_drag_finish (context, TRUE, FALSE, time);
+			gtk_drag_finish (context, TRUE, FALSE, timestamp);
 		}
 	}
 	else
 	{
-		GTK_WIDGET_CLASS (gedit_view_parent_class)->drag_data_received (widget, context, x, y, selection_data, info, time);
+		GTK_WIDGET_CLASS (gedit_view_parent_class)->drag_data_received (widget, context, x, y, selection_data, info, timestamp);
 	}
 }
 
@@ -1988,7 +1951,7 @@ gedit_view_drag_drop (GtkWidget      *widget,
 		      GdkDragContext *context,
 		      gint            x,
 		      gint            y,
-		      guint           time)
+		      guint           timestamp)
 {
 	gboolean result;
 	GdkAtom target;
@@ -1998,13 +1961,13 @@ gedit_view_drag_drop (GtkWidget      *widget,
 
 	if (target != GDK_NONE)
 	{
-		gtk_drag_get_data (widget, context, target, time);
+		gtk_drag_get_data (widget, context, target, timestamp);
 		result = TRUE;
 	}
 	else
 	{
 		/* Chain up */
-		result = GTK_WIDGET_CLASS (gedit_view_parent_class)->drag_drop (widget, context, x, y, time);
+		result = GTK_WIDGET_CLASS (gedit_view_parent_class)->drag_drop (widget, context, x, y, timestamp);
 	}
 
 	return result;
