@@ -625,6 +625,17 @@ message_remove_context_item_cb (GeditMessageBus *bus,
 	gtk_ui_manager_remove_ui (manager, merge_id);
 }
 
+static void
+message_get_view_cb (GeditMessageBus *bus,
+		     GeditMessage    *message,
+		     WindowData      *data)
+{
+	GeditFileBrowserView *view;
+	view = gedit_file_browser_widget_get_browser_view (data->widget);
+
+	gedit_message_set (message, "view", view, NULL);
+}
+
 static void
 register_methods (GeditWindow            *window,
 		  GeditFileBrowserWidget *widget)
@@ -670,8 +681,9 @@ register_methods (GeditWindow            *window,
 	gedit_message_bus_register (bus,
 				    MESSAGE_OBJECT_PATH, "add_context_item",
 				    1,
-    				    "action", GTK_TYPE_ACTION,
-    				    "id", G_TYPE_UINT,
+				    "action", GTK_TYPE_ACTION,
+				    "path", G_TYPE_STRING,
+				    "id", G_TYPE_UINT,
 				    NULL);
 
 	gedit_message_bus_register (bus,
@@ -701,6 +713,12 @@ register_methods (GeditWindow            *window,
 	gedit_message_bus_register (bus, MESSAGE_OBJECT_PATH, "show_bookmarks", 0, NULL);
 	gedit_message_bus_register (bus, MESSAGE_OBJECT_PATH, "show_files", 0, NULL);
 
+	gedit_message_bus_register (bus,
+				    MESSAGE_OBJECT_PATH, "get_view",
+				    1,
+				    "view", GEDIT_TYPE_FILE_BROWSER_VIEW,
+				    NULL);
+
 	BUS_CONNECT (bus, get_root, data);
 	BUS_CONNECT (bus, set_root, data);
 	BUS_CONNECT (bus, set_emblem, data);
@@ -721,6 +739,8 @@ register_methods (GeditWindow            *window,
 	
 	BUS_CONNECT (bus, show_bookmarks, data);
 	BUS_CONNECT (bus, show_files, data);
+
+	BUS_CONNECT (bus, get_view, data);
 }
 
 static void
@@ -998,7 +1018,7 @@ cleanup_signals (GeditWindow *window)
 	g_signal_handler_disconnect (store, data->begin_loading_id);
 	g_signal_handler_disconnect (store, data->end_loading_id);
 	
-	g_signal_handlers_disconnect_by_func (data->bus, "unregistered", window);
+	g_signal_handlers_disconnect_by_func (data->bus, message_unregistered, window);
 }
 
 void
